from setuptools import setup

setup(name='scikitsampledistribution',
      version='0.1',
      description='Gaussian distributions',
      packages=['scikitsampledistribution'],
      zip_safe=False)
